get_gas_price_or_default

Function get_gas_price_or_default 

pub fn get_gas_price_or_default(gas_price: Option<u64>) -> u64
Gets the gas price or returns the default value if not provided.

Arguments

  • gas_price - An optional gas price value.

Returns

The gas price or the default gas price if not provided.